# P2obt
<!-- Project Shields -->
[![License: MIT](https://img.shields.io/badge/license-MIT-green.svg)](https://opensource.org/licenses/MIT)
![Lifecycle: production](https://img.shields.io/badge/lifecycle-production-orange.svg)

The Phase 2 OB tool (p2obt) has been made to streamline/automate
the process of MATISSE observation (ob) preparation on p2.

More information can be found in the [**documentation**](https://mbsck.github.io/p2obt/) and for quick access under the following links: 

* [**Installation**](https://mbsck.github.io/p2obt/installation.html)
* [**Getting Started**](https://mbsck.github.io/p2obt/getting_started.html) (supplemented by scripts in the `example/` directory).
* [**Bug Reports/Issues**](https://github.com/mbsck/p2obt/issues)
* [**Credit**](https://mbsck.github.io/p2obt/credit.html)

If you feel this tool is useful, feel free to star it!
